@@ -10,7 +10,6 @@
 
 from __future__ import absolute_import, division, print_function
 
-# from PIL import Image 
 import matplotlib.pyplot as plt
 import os
 import imagecodecs
@@ -195,7 +194,9 @@ def imshow(parameter):
 read = imread
 save = imwrite
 show = imshow
+imload = imread
+imsave = imwrite
 
 
 if __name__ == "__main__":
-	pass
\ No newline at end of file
+	pass
