@@ -7,12 +7,10 @@
 # Date: 6th Aug 2016
 # ==============================
 """
-# import png
-# import scipy.misc
 import numpy as np
 import matplotlib.colors as cl
 import matplotlib.pyplot as plt
-# from PIL import Image
+import cv2
 
 
 UNKNOWN_FLOW_THRESH = 1e7
@@ -585,4 +583,4 @@ def make_color_wheel():
     return colorwheel
 
 if __name__ == "__main__":
-    pass
\ No newline at end of file
+    pass
